@@ -56,7 +56,7 @@ __license__ = "Apache-2.0"
 # do not change this line manually
 # this is managed by git tag and updated on every release
 # NOTE: this represents the NEXT release version
-__version__ = '1.1.6'
+__version__ = '1.1.9'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
@@ -200,7 +200,7 @@ from jina.clients import Client
 from jina.clients.asyncio import AsyncClient
 
 # Executor
-from jina.executors import BaseExecutor as Executor
+from jina.executors import GenericExecutor as Executor
 from jina.executors.classifiers import BaseClassifier as Classifier
 from jina.executors.crafters import BaseCrafter as Crafter
 from jina.executors.encoders import BaseEncoder as Encoder
@@ -208,6 +208,7 @@ from jina.executors.evaluators import BaseEvaluator as Evaluator
 from jina.executors.indexers import BaseIndexer as Indexer
 from jina.executors.rankers import BaseRanker as Ranker
 from jina.executors.segmenters import BaseSegmenter as Segmenter
+from jina.executors.decorators import requests
 
 __all__ = [_s for _s in dir() if not _s.startswith('_')]
 __all__.extend([_s for _s in _names_with_underscore])
