@@ -2,6 +2,8 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
+from typing import Union, List
+
 from . import request
 from .base import BaseClient, CallbackFnType, InputType, InputDeleteType
 from .helper import callback_exec
@@ -38,7 +40,7 @@ class Client(BaseClient):
         on_done: CallbackFnType = None,
         on_error: CallbackFnType = None,
         on_always: CallbackFnType = None,
-        **kwargs
+        **kwargs,
     ) -> None:
         """Issue 'train' request to the Flow.
 
@@ -66,7 +68,7 @@ class Client(BaseClient):
         on_done: CallbackFnType = None,
         on_error: CallbackFnType = None,
         on_always: CallbackFnType = None,
-        **kwargs
+        **kwargs,
     ) -> None:
         """Issue 'search' request to the Flow.
 
@@ -95,7 +97,7 @@ class Client(BaseClient):
         on_done: CallbackFnType = None,
         on_error: CallbackFnType = None,
         on_always: CallbackFnType = None,
-        **kwargs
+        **kwargs,
     ) -> None:
         """Issue 'index' request to the Flow.
 
@@ -123,7 +125,7 @@ class Client(BaseClient):
         on_done: CallbackFnType = None,
         on_error: CallbackFnType = None,
         on_always: CallbackFnType = None,
-        **kwargs
+        **kwargs,
     ) -> None:
         """Issue 'update' request to the Flow.
 
@@ -151,7 +153,7 @@ class Client(BaseClient):
         on_done: CallbackFnType = None,
         on_error: CallbackFnType = None,
         on_always: CallbackFnType = None,
-        **kwargs
+        **kwargs,
     ) -> None:
         """Issue 'update' request to the Flow.
 
@@ -167,6 +169,39 @@ class Client(BaseClient):
             self._get_results, inputs, on_done, on_error, on_always, **kwargs
         )
 
+    def reload(
+        self,
+        targets: Union[str, List[str]],
+        on_done: CallbackFnType = None,
+        on_error: CallbackFnType = None,
+        on_always: CallbackFnType = None,
+        **kwargs,
+    ):
+        """Send 'reload' request to the Flow.
+
+        :param targets: the regex string or list of regex strings to match the pea/pod names.
+        :param on_done: the function to be called when the :class:`Request` object is resolved.
+        :param on_error: the function to be called when the :class:`Request` object is rejected.
+        :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
+        :param kwargs: additional parameters
+        :return: None
+        """
+
+        if isinstance(targets, str):
+            targets = [targets]
+        kwargs['targets'] = targets
+
+        self.mode = RequestType.CONTROL
+        return run_async(
+            self._get_results,
+            [],
+            on_done,
+            on_error,
+            on_always,
+            command='RELOAD',
+            **kwargs,
+        )
+
 
 class WebSocketClient(Client, WebSocketClientMixin):
     """A Python Client to stream requests from a Flow with a REST Gateway.
