@@ -1,31 +1,32 @@
-from typing import List, Any, Union, Tuple, Optional
+from typing import List, Any, Union, Optional
 
 import numpy as np
 
-from . import BaseExecutableDriver, FlatRecursiveMixin
+from . import BaseExecutableDriver, FlatRecursiveMixin, DocsExtractUpdateMixin
 from ..helper import typename
 
 if False:
     from ..types.sets import DocumentSet
+    from ..types.document import Document
 
 
-class BasePredictDriver(FlatRecursiveMixin, BaseExecutableDriver):
+class BasePredictDriver(
+    DocsExtractUpdateMixin, FlatRecursiveMixin, BaseExecutableDriver
+):
     """Drivers inherited from :class:`BasePredictDriver` will bind :meth:`predict` by default
 
     :param fields: name of fields to be used to predict tags, default "embeddings"
-    :param *args: *args for super
-    :param **kwargs: **kwargs for super
+    :param args: additional positional arguments which are just used for the parent initialization
+    :param kwargs: additional key value arguments which are just used for the parent initialization
     """
 
     def __init__(
         self,
         executor: Optional[str] = None,
         method: str = 'predict',
-        fields: Union[Tuple, str] = 'embedding',
         *args,
         **kwargs,
     ):
-        self.fields = fields
         super().__init__(executor, method, *args, **kwargs)
 
 
@@ -33,36 +34,25 @@ class BaseLabelPredictDriver(BasePredictDriver):
     """Base class of a Driver for label prediction.
 
     :param output_tag: output label will be written to ``doc.tags``
-    :param *args: *args for super
-    :param **kwargs: **kwargs for super
+    :param args: additional positional arguments which are just used for the parent initialization
+    :param kwargs: additional key value arguments which are just used for the parent initialization
     """
 
     def __init__(self, output_tag: str = 'prediction', *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.output_tag = output_tag
 
-    def _apply_all(
-        self,
-        docs: 'DocumentSet',
-        *args,
-        **kwargs,
-    ) -> None:
-        if self.fields == 'embedding':
-            predict_input, docs_pts = docs.all_embeddings
-        elif self.fields == 'content':
-            predict_input, docs_pts = docs.all_contents
-        else:
-            raise ValueError(
-                f'{self.fields} is not a valid field name for {self!r}, must be one of embeddings, contents'
-            )
+    def update_docs(self, docs_pts: 'DocumentSet', exec_results: Any):
+        """Update doc tags attribute with executor's return
 
-        if docs_pts:
-            prediction = self.exec_fn(predict_input)
-            labels = self.prediction2label(
-                prediction
-            )  # type: List[Union[str, List[str]]]
-            for doc, label in zip(docs_pts, labels):
-                doc.tags[self.output_tag] = label
+        :param: docs_pts: the set of document to be updated
+        :param: exec_results: the results from :meth:`exec_fn`
+        """
+        labels = self.prediction2label(
+            exec_results
+        )  # type: List[Union[str, List[str]]]
+        for doc, label in zip(docs_pts, labels):
+            doc.tags[self.output_tag] = label
 
     def prediction2label(self, prediction: 'np.ndarray') -> List[Any]:
         """Converting ndarray prediction into list of readable labels
@@ -84,19 +74,15 @@ class BaseLabelPredictDriver(BasePredictDriver):
 
 
 class BinaryPredictDriver(BaseLabelPredictDriver):
-    """Converts binary prediction into string label.
+    """Converts binary prediction into string label. This is often used with binary classifier.
 
-    This is often used with binary classifier.
+    :param one_label: label when prediction is one
+    :param zero_label: label when prediction is zero
+    :param args: additional positional arguments which are just used for the parent initialization
+    :param kwargs: additional key value arguments which are just used for the parent initialization
     """
 
     def __init__(self, one_label: str = 'yes', zero_label: str = 'no', *args, **kwargs):
-        """
-
-        :param one_label: label when prediction is one
-        :param zero_label: label when prediction is zero
-        :param *args: *args for super
-        :param **kwargs: **kwargs for super
-        """
         super().__init__(*args, **kwargs)
         self.one_label = one_label
         self.zero_label = zero_label
@@ -187,22 +173,10 @@ class Prediction2DocBlobDriver(BasePredictDriver):
         This will erase the content in ``document.text`` and ``document.buffer``.
     """
 
-    def _apply_all(
-        self,
-        docs: 'DocumentSet',
-        *args,
-        **kwargs,
-    ) -> None:
-        if self.fields == 'embedding':
-            predict_input, docs_pts = docs.all_embeddings
-        elif self.fields == 'content':
-            predict_input, docs_pts = docs.all_contents
-        else:
-            raise ValueError(
-                f'{self.fields} is not a valid field name for {self!r}, must be one of embeddings, contents'
-            )
+    def update_single_doc(self, doc: 'Document', exec_result: Any) -> None:
+        """Update doc blob with executor's return.
 
-        if docs_pts:
-            prediction = self.exec_fn(predict_input)
-            for doc, pred in zip(docs_pts, prediction):
-                doc.blob = pred
+        :param doc: the Document object
+        :param exec_result: the single result from :meth:`exec_fn`
+        """
+        doc.blob = exec_result
