@@ -11,6 +11,7 @@ from . import (
 )
 from ..types.document import Document
 from ..types.score import NamedScore
+from ..enums import EmbeddingClsType
 
 if False:
     from ..types.sets import DocumentSet
@@ -122,30 +123,23 @@ class VectorSearchDriver(FlatRecursiveMixin, QuerySetReader, BaseSearchDriver):
         self._fill_embedding = fill_embedding
 
     @property
-    def exec_embedding_cls_type(self) -> str:
+    def exec_embedding_cls_type(self) -> EmbeddingClsType:
         """Get the sparse class type of the attached executor.
 
-        :return: Embedding class type of the attached executor, default value is `dense`.
+        :return: Embedding class type of the attached executor, default value is `dense`
         """
-        return self.exec.embedding_cls_type
+        return EmbeddingClsType.from_string(self.exec.embedding_cls_type)
 
     def _get_documents_embeddings(self, docs: 'DocumentSet'):
         embedding_cls_type = self.exec_embedding_cls_type
-        if embedding_cls_type == 'dense':
+        if embedding_cls_type.is_dense:
             return docs.all_embeddings
         else:
-            scipy_cls_type = None
-            if embedding_cls_type.startswith('scipy'):
-                scipy_cls_type = embedding_cls_type.split('_')[1]
-                embedding_cls_type = 'scipy'
-
-            return docs.get_all_sparse_embeddings(
-                sparse_cls_type=embedding_cls_type, scipy_cls_type=scipy_cls_type
-            )
+            return docs.get_all_sparse_embeddings(embedding_cls_type=embedding_cls_type)
 
     def _fill_matches(self, doc, op_name, topks, scores, topk_embed):
         embedding_cls_type = self.exec_embedding_cls_type
-        if embedding_cls_type == 'dense':
+        if embedding_cls_type.is_dense:
             for numpy_match_id, score, vector in zip(topks, scores, topk_embed):
                 m = Document(id=numpy_match_id)
                 m.score = NamedScore(op_name=op_name, value=score)
@@ -155,12 +149,12 @@ class VectorSearchDriver(FlatRecursiveMixin, QuerySetReader, BaseSearchDriver):
         else:
             for idx, (numpy_match_id, score) in enumerate(zip(topks, scores)):
                 vector = None
-                if topk_embed is not None:
+                if topk_embed[idx] is not None:
                     vector = topk_embed.getrow(idx)
                 m = Document(id=numpy_match_id)
                 m.score = NamedScore(op_name=op_name, value=score)
                 match = doc.matches.append(m)
-                if vector:
+                if vector is not None:
                     match.embedding = vector
 
     def _apply_all(self, docs: 'DocumentSet', *args, **kwargs) -> None:
