@@ -3,19 +3,6 @@ Miscellaneous enums used in Jina.
 
 To use these enums in YAML config, following the example below:
 
-.. highlight:: yaml
-.. code-block:: yaml
-
-    !Flow
-    with:
-      optimize_level: !FlowOptimizeLevel IGNORE_GATEWAY
-      # or
-      optimize_level: IGNORE_GATEWAY
-      #or
-      optimize_level: ignore_gateway
-      no_gateway: true
-
-
 .. highlight:: yaml
 .. code-block:: yaml
 
@@ -39,6 +26,12 @@ class EnumType(EnumMeta):
     """The metaclass for BetterEnum."""
 
     def __new__(cls, *args, **kwargs):
+        """Register a new EnumType
+
+        :param args: args passed to super()
+        :param kwargs: kwargs passed to super()
+        :return: the registry class
+        """
         _cls = super().__new__(cls, *args, **kwargs)
         return cls.register_class(_cls)
 
@@ -55,6 +48,7 @@ class EnumType(EnumMeta):
             reg_cls_set.add(cls.__name__)
             setattr(cls, '_registered_class', reg_cls_set)
         from .jaml import JAML
+
         JAML.register(cls)
         return cls
 
@@ -67,11 +61,18 @@ class BetterEnum(IntEnum, metaclass=EnumType):
 
     @classmethod
     def from_string(cls, s: str):
-        """Parse the enum from a string."""
+        """
+        Parse the enum from a string.
+
+        :param s: string representation of the enum value
+        :return: enum value
+        """
         try:
             return cls[s.upper()]
         except KeyError:
-            raise ValueError(f'{s.upper()} is not a valid enum for {cls!r}, must be one of {list(cls)}')
+            raise ValueError(
+                f'{s.upper()} is not a valid enum for {cls!r}, must be one of {list(cls)}'
+            )
 
     @classmethod
     def _to_yaml(cls, representer, data):
@@ -80,8 +81,13 @@ class BetterEnum(IntEnum, metaclass=EnumType):
         .. note::
             In principle, this should inherit from :class:`JAMLCompatible` directly,
             however, this method is too simple and thus replaced the parent method.
+        :param representer: pyyaml representer
+        :param data: enum value
+        :return: yaml representation
         """
-        return representer.represent_scalar('!' + cls.__name__, str(data))
+        return representer.represent_scalar(
+            'tag:yaml.org,2002:str', str(data), style='"'
+        )
 
     @classmethod
     def _from_yaml(cls, constructor, node):
@@ -90,6 +96,9 @@ class BetterEnum(IntEnum, metaclass=EnumType):
         .. note::
             In principle, this should inherit from :class:`JAMLCompatible` directly,
             however, this method is too simple and thus replaced the parent method.
+        :param constructor: unused
+        :param node: node to derive the enum value from
+        :return: enum value
         """
         return cls.from_string(node.value)
 
@@ -127,14 +136,6 @@ class PollingType(BetterEnum):
         return self.value == 2
 
 
-class FlowOptimizeLevel(BetterEnum):
-    """The level of flow optimization."""
-
-    NONE = 0
-    IGNORE_GATEWAY = 1
-    FULL = 2
-
-
 class LogVerbosity(BetterEnum):
     """Verbosity level of the logger."""
 
@@ -206,7 +207,7 @@ class SocketType(BetterEnum):
             SocketType.PUSH_BIND: SocketType.PULL_CONNECT,
             SocketType.PUB_CONNECT: SocketType.SUB_BIND,
             SocketType.PUB_BIND: SocketType.SUB_CONNECT,
-            SocketType.PAIR_CONNECT: SocketType.PAIR_BIND
+            SocketType.PAIR_CONNECT: SocketType.PAIR_BIND,
         }[self]
 
 
@@ -268,6 +269,8 @@ class RequestType(BetterEnum):
     UPDATE = 3
     CONTROL = 4
     TRAIN = 5
+    # TODO make Dump a control request to be passed to the Pod directly
+    DUMP = 6
 
 
 class CompressAlgo(BetterEnum):
@@ -301,7 +304,9 @@ class OnErrorStrategy(BetterEnum):
         side-effect.
     """
 
-    IGNORE = 0  #: Ignore it, keep running all Drivers & Executors logics in the sequel flow
+    IGNORE = (
+        0  #: Ignore it, keep running all Drivers & Executors logics in the sequel flow
+    )
     SKIP_EXECUTOR = 1  #: Skip all Executors in the sequel, but drivers are still called
     SKIP_HANDLE = 2  #: Skip all Drivers & Executors in the sequel, only `pre_hook` and `post_hook` are called
     THROW_EARLY = 3  #: Immediately throw the exception, the sequel flow will not be running at all
@@ -356,6 +361,82 @@ class RuntimeBackendType(BetterEnum):
     PROCESS = 1
 
 
+class EmbeddingClsType(BetterEnum):
+    """Enums for representing the type of embeddings supported."""
+
+    DENSE = 0
+    SCIPY_COO = 1
+    SCIPY_CSR = 2
+    SCIPY_BSR = 3
+    SCIPY_CSC = 4
+    TORCH = 5
+    TF = 6
+
+    @property
+    def is_sparse(self) -> bool:
+        """
+        Check if is of sparse type
+
+        :return: True if the type is sparse
+        """
+        return self.value != 0
+
+    @property
+    def is_dense(self) -> bool:
+        """
+        Check if is of dense type
+
+        :return: True if the type is dense
+        """
+        return self.value == 0
+
+    @property
+    def is_scipy(self) -> bool:
+        """
+        Check if is of scipy sparse type
+
+        :return: True is of scipy sparse type
+        """
+        return self.value in [1, 2, 3, 4]
+
+    @property
+    def is_torch(self) -> bool:
+        """
+        Check if is of torch sparse type
+
+        :return: True is of torch sparse type
+        """
+        return self.value == 5
+
+    @property
+    def is_tf(self) -> bool:
+        """
+        Check if is of tf sparse type
+
+        :return: True is of tf sparse type
+        """
+        return self.value == 6
+
+    @property
+    def scipy_cls_type(self) -> str:
+        """
+        Return the specific scipy class type (coo, csr, csc, bsr)
+
+        :return: True is of scipy sparse type
+        """
+        if self.is_scipy:
+            return self.name.split('_')[1].lower()
+
+    @property
+    def is_scipy_stackable(self) -> bool:
+        """
+        Return if the specific scipy class is stackable. (BSR and CSC when stacked are converted into COO)
+
+        :return: True is class is stackable
+        """
+        return self.value in [1, 2]
+
+
 def replace_enum_to_str(obj):
     """
     Transform BetterEnum type into string.
