@@ -9,28 +9,32 @@ from ..compound import CompoundExecutor
 
 
 class BaseEvaluator(BaseExecutor):
-    """A :class:`BaseEvaluator` is used to evaluate different messages coming from any kind of executor
-    """
+    """A :class:`BaseEvaluator` is used to evaluate different messages coming from any kind of executor"""
 
     metric = ''  #: Get the name of the evaluation metric
 
     def post_init(self):
+        """Initialize running stats."""
         super().post_init()
         self._running_stats = RunningStats()
 
     def evaluate(self, actual: Any, desired: Any, *args, **kwargs) -> float:
+        """Evaluates difference between param:`actual` and `param:desired`, needs to be implemented in subclass."""
         raise NotImplementedError
 
     @property
     def mean(self) -> float:
+        """Get the running mean."""
         return self._running_stats.mean
 
     @property
     def std(self) -> float:
+        """Get the running standard variance."""
         return self._running_stats.std
 
     @property
     def variance(self) -> float:
+        """Get the running variance."""
         return self._running_stats.variance
 
 
@@ -78,4 +82,4 @@ class FileBasedEvaluator(CompoundExecutor):
                  executor: BaseEvaluator
            ControlRequest:
              - !ControlReqDriver {}
-     """
+    """
