@@ -1,4 +1,4 @@
-"""The default meta config that all executors follow, they can be overrided by the YAML config
+"""The default meta config that all executors follow, they can be overridden by the YAML config
 
 .. warning::
 
@@ -15,14 +15,6 @@
 
 Any executor inherited from :class:`BaseExecutor` always has the following **meta** fields:
 
-    .. confval:: is_trained
-
-        indicates if the executor is trained or not, if not then methods decorated by :func:`@required_train`
-        can not be executed.
-
-        :type: bool
-        :default: ``False``
-
     .. confval:: is_updated
 
         indicates if the executor is updated or changed since last save, if not then :func:`save` will do nothing.
@@ -47,7 +39,7 @@ Any executor inherited from :class:`BaseExecutor` always has the following **met
         By default it is not set, if you expect your executor to be persisted or to persist any data, remember to set it
         to the desired value.
 
-        When a `BaseExecutor` is a component of a `CompoundExecutor`, its `workspace` value will be overriden by the `workspace`
+        When a `BaseExecutor` is a component of a `CompoundExecutor`, its `workspace` value will be overridden by the `workspace`
         coming from the `CompoundExecutor` unless a particular `workspace` value is set for the component `BaseExecutor`.
 
         :type: str
@@ -154,9 +146,9 @@ Any executor inherited from :class:`BaseExecutor` always has the following **met
     .. note::
 
         ``pea_id`` is set in a way that when the executor ``A`` is used as
-        a component of a :class:`jina.executors.compound.CompoundExecutor` ``B``, then ``A``'s setting will be overrided by B's counterpart.
+        a component of a :class:`jina.executors.compound.CompoundExecutor` ``B``, then ``A``'s setting will be overridden by B's counterpart.
 
-    These **meta** fields can be accessed via `self.is_trained` or loaded from a YAML config via :func:`load_config`:
+    These **meta** fields can be accessed via `self.name` or loaded from a YAML config via :func:`load_config`:
 
     .. highlight:: yaml
     .. code-block:: yaml
@@ -166,7 +158,6 @@ Any executor inherited from :class:`BaseExecutor` always has the following **met
           ...
         metas:
           name: my_transformer  # a customized name
-          is_trained: true  # indicate the model has been trained
           workspace: ./  # path for serialize/deserialize
 
 
@@ -183,7 +174,11 @@ _defaults = None
 
 
 def get_default_metas() -> Dict:
-    """Get a copy of default meta variables"""
+    """
+    Get a copy of default meta variables.
+
+    :return: default metas
+    """
     import copy
 
     global _defaults
@@ -191,8 +186,13 @@ def get_default_metas() -> Dict:
     if _defaults is None:
         from ..jaml import JAML
         from pkg_resources import resource_stream
-        with resource_stream('jina', '/'.join(('resources', 'executors.metas.default.yml'))) as fp:
-            _defaults = JAML.load(fp)  # do not expand variables at here, i.e. DO NOT USE expand_dict(yaml.load(fp))
+
+        with resource_stream(
+            'jina', '/'.join(('resources', 'executors.metas.default.yml'))
+        ) as fp:
+            _defaults = JAML.load(
+                fp
+            )  # do not expand variables at here, i.e. DO NOT USE expand_dict(yaml.load(fp))
 
     return copy.deepcopy(_defaults)
 
@@ -201,6 +201,7 @@ def fill_metas_with_defaults(d: Dict) -> Dict:
     """Fill the incomplete ``metas`` field with complete default values
 
     :param d: the loaded YAML map
+    :return: dictionary with injected metas
     """
 
     def _scan(sub_d: Union[Dict, List]):
