@@ -470,12 +470,12 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         op_flow = _build_flow(op_flow, _outgoing_map)
         hanging_pods = _hanging_pods(op_flow)
         if hanging_pods:
-            self.logger.warning(
+            op_flow.logger.warning(
                 f'{hanging_pods} are hanging in this flow with no pod receiving from them, '
                 f'you may want to double check if it is intentional or some mistake'
             )
         op_flow._build_level = FlowBuildLevel.GRAPH
-        self._update_client()
+        op_flow._update_client()
         return op_flow
 
     def __call__(self, *args, **kwargs):
@@ -966,3 +966,14 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     # for backward support
     join = needs
+
+    def dump(self, pod_name, path: str, shards: int, timeout=-1):
+        """Emit a Dump request to a specific Pod
+
+        :param shards: the nr of shards in the dump
+        :param path: the path to which to dump
+        :param pod_name: the name of the pod
+        :param timeout: time to wait (seconds)
+        """
+        pod = self._pod_nodes[pod_name]
+        pod.dump(path, shards, timeout)
