@@ -1,4 +1,4 @@
-__copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
+__copyright__ = "Copyright (c) 2021 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
 import os
@@ -13,10 +13,19 @@ from jina.excepts import PretrainedModelFileDoesNotExist
 
 class CustomImageTorchEncoder(BaseTorchEncoder):
     """
-    :class:`CustomImageTorchEncoder` encodes data from a ndarray, potentially B x (Channel x Height x Width) into a
-        ndarray of `B x D`.
-    Internally, :class:`CustomImageTorchEncoder` wraps any custom torch model not part of models from `torchvision.models`.
+    :class:`CustomImageTorchEncoder` encodes ``Document`` content from a ndarray,
+    potentially B x (Channel x Height x Width) into a ndarray of `B x D`.
+
+    Internally, :class:`CustomImageTorchEncoder` wraps any custom torch
+    model not part of models from `torchvision.models`.
     https://pytorch.org/docs/stable/torchvision/models.html
+
+    :param model_path: The path where the model is stored.
+    :param layer_name: Name of the layer from where to extract the feature map.
+    :param pool_strategy: Pooling strategy for the encoder. Default is `mean`.
+    :param channel_axis: The axis of the channel, default is 1.
+    :param args:  Additional positional arguments.
+    :param kwargs: Additional keyword arguments.
     """
 
     def __init__(self, model_path: Optional[str] = 'models/mobilenet_v2.pth',
@@ -24,10 +33,6 @@ class CustomImageTorchEncoder(BaseTorchEncoder):
                  pool_strategy: str = 'mean',
                  channel_axis: int = 1,
                  *args, **kwargs):
-        """
-        :param model_path: the path where the model is stored.
-        :layer: Name of the layer from where to extract the feature map.
-        """
         super().__init__(*args, **kwargs)
         self.model_path = model_path
         self.layer_name = layer_name
@@ -37,6 +42,7 @@ class CustomImageTorchEncoder(BaseTorchEncoder):
         self.pool_strategy = pool_strategy
 
     def post_init(self):
+        """Load model. Will raise an exception if the model doesn't exist."""
         super().post_init()
         if self.model_path and os.path.exists(self.model_path):
             import torch
@@ -49,15 +55,15 @@ class CustomImageTorchEncoder(BaseTorchEncoder):
         else:
             raise PretrainedModelFileDoesNotExist(f'model {self.model_path} does not exist')
 
-    def _get_features(self, data):
+    def _get_features(self, content):
         feature_map = None
 
-        def get_activation(model, input, output):
+        def get_activation(model, model_input, output):
             nonlocal feature_map
             feature_map = output.detach()
 
         handle = self.layer.register_forward_hook(get_activation)
-        self.model(data)
+        self.model(content)
         handle.remove()
         return feature_map
 
@@ -68,14 +74,23 @@ class CustomImageTorchEncoder(BaseTorchEncoder):
 
     @batching
     @as_ndarray
-    def encode(self, data: 'np.ndarray', *args, **kwargs) -> 'np.ndarray':
+    def encode(self, content: 'np.ndarray', *args, **kwargs) -> 'np.ndarray':
+        """
+        Encode input data into `np.ndarray` of size `B x D`.
+        Where `B` is the batch size and `D` is the Dimension.
+
+        :param content: An array in size `B`.
+        :param args:  Additional positional arguments.
+        :param kwargs: Additional keyword arguments.
+        :return: An ndarray in size `B x D`.
+        """
         if self.channel_axis != self._default_channel_axis:
-            data = np.moveaxis(data, self.channel_axis, self._default_channel_axis)
+            content = np.moveaxis(content, self.channel_axis, self._default_channel_axis)
         import torch
-        _input = torch.from_numpy(data.astype('float32'))
+        _input = torch.from_numpy(content.astype('float32'))
         if self.on_gpu:
             _input = _input.cuda()
-        _feature = self._get_features(_input).detach()
+        _feature = self._get_features(content=_input).detach()
         if self.on_gpu:
             _feature = _feature.cpu()
         _feature = _feature.numpy()
