@@ -6,9 +6,9 @@ from jina.executors.encoders.numeric import TransformEncoder
 
 class FastICAEncoder(TransformEncoder):
     """
-    Encodes data using a fast algorithm for Independent Component Analysis (FastICA)
+    Encodes ``Document`` content using a fast algorithm for Independent Component Analysis (FastICA)
 
-    Encodes data from an ndarray in size `B x T` into an ndarray in size `B x D`.
+    Encodes content from an ndarray in size `B x T` into an ndarray in size `B x D`.
     Where `B` is the batch's size and `T` and `D` are the dimensions pre (`T`)
     and after (`D`) the encoding.
     """
\ No newline at end of file
