@@ -1,18 +1,32 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
-from jina.executors.decorators import batching, as_ndarray
 import numpy as np
+
+from jina.executors.decorators import batching, as_ndarray
 from jina.executors.encoders import BaseVideoEncoder
 from jina.executors.encoders.frameworks import BaseTorchEncoder
 
 
 class VideoTorchEncoder(BaseTorchEncoder, BaseVideoEncoder):
     """
-    :class:`VideoTorchEncoder` encodes data from a ndarray, potentially B x T x (Channel x Height x Width) into an
-        ndarray of `B x D`.
-    Internally, :class:`VideoTorchEncoder` wraps the models from `torchvision.models`.
-    https://pytorch.org/docs/stable/torchvision/models.html
+    Encode `Document` content from a ndarray, using the models from `torchvision.models`.
+
+    :class:`VideoTorchEncoder` encodes content from a ndarray, potentially
+    B x T x (Channel x Height x Width) into an ndarray of `B x D`.
+    Internally, :class:`VideoTorchEncoder` wraps the models from
+    `torchvision.models`: https://pytorch.org/docs/stable/torchvision/models.html
+
+    :param model_name: the name of the model.
+        Supported models include ``r3d_18``, ``mc3_18``, ``r2plus1d_18``
+        Default is ``r3d_18``.
+    :param pool_strategy: the pooling strategy
+        - `None` means that the output of the model will be the 4D tensor
+            output of the last convolutional block.
+        - `mean` means that global average pooling will be applied to the
+            output of the last convolutional block, and thus the output
+            of the model will be a 2D tensor.
+        - `max` means that global max pooling will be applied.
     """
 
     def __init__(self,
@@ -20,14 +34,6 @@ class VideoTorchEncoder(BaseTorchEncoder, BaseVideoEncoder):
                  channel_axis: int = 1,
                  pool_strategy: str = 'mean',
                  *args, **kwargs):
-        """
-        :param model_name: the name of the model. Supported models include ``r3d_18``, ``mc3_18``, ``r2plus1d_18``
-        :param pool_strategy: the pooling strategy
-            - `None` means that the output of the model will be the 4D tensor output of the last convolutional block.
-            - `mean` means that global average pooling will be applied to the output of the last convolutional block, and
-                 thus the output of the model will be a 2D tensor.
-            - `max` means that global max pooling will be applied.
-        """
         super().__init__(*args, **kwargs)
         self.channel_axis = channel_axis
         self.model_name = model_name
@@ -37,6 +43,7 @@ class VideoTorchEncoder(BaseTorchEncoder, BaseVideoEncoder):
         self.pool_strategy = pool_strategy
 
     def post_init(self):
+        """Load Torch model"""
         super().post_init()
         import torchvision.models.video as models
         if self.pool_strategy is not None:
@@ -61,15 +68,22 @@ class VideoTorchEncoder(BaseTorchEncoder, BaseVideoEncoder):
 
     @batching
     @as_ndarray
-    def encode(self, data: 'np.ndarray', *args, **kwargs) -> 'np.ndarray':
+    def encode(self, content: 'np.ndarray', *args, **kwargs) -> 'np.ndarray':
+        """
+         Encode ``Document`` content from a ndarray.
+
+         :param content: a `B x T x (Channel x Height x Width)` numpy ``ndarray``,
+            `B` is the size of the batch, `T` is the number of frames
+         :return: a `B x D` numpy ``ndarray``, `D` is the output dimension
+        """
         if self.channel_axis != self._default_channel_axis:
-            data = np.moveaxis(data, self.channel_axis, self._default_channel_axis)
+            content = np.moveaxis(content, self.channel_axis, self._default_channel_axis)
         import torch
-        _input = torch.from_numpy(data.astype('float32'))
+        _input = torch.from_numpy(content.astype('float32'))
         if self.on_gpu:
             _input = _input.cuda()
         _feature = self._get_features(_input).detach()
-        if self.on_gpu:
+        if not self.on_gpu:
             _feature = _feature.cpu()
         _feature = _feature.numpy()
         return self._get_pooling(_feature)
\ No newline at end of file
