@@ -10,19 +10,26 @@ from ...helper import random_identity, typename
 from ...proto import jina_pb2
 
 _body_type = set(str(v).lower() for v in RequestType)
-_trigger_body_fields = set(kk
-                           for v in [jina_pb2.RequestProto.IndexRequestProto,
-                                     jina_pb2.RequestProto.SearchRequestProto,
-                                     jina_pb2.RequestProto.TrainRequestProto,
-                                     jina_pb2.RequestProto.ControlRequestProto]
-                           for kk in v.DESCRIPTOR.fields_by_name.keys())
-_trigger_req_fields = set(jina_pb2.RequestProto.DESCRIPTOR.fields_by_name.keys()).difference(_body_type)
+_trigger_body_fields = set(
+    kk
+    for v in [
+        jina_pb2.RequestProto.IndexRequestProto,
+        jina_pb2.RequestProto.SearchRequestProto,
+        jina_pb2.RequestProto.TrainRequestProto,
+        jina_pb2.RequestProto.ControlRequestProto,
+    ]
+    for kk in v.DESCRIPTOR.fields_by_name.keys()
+)
+_trigger_req_fields = set(
+    jina_pb2.RequestProto.DESCRIPTOR.fields_by_name.keys()
+).difference(_body_type)
 _trigger_fields = _trigger_req_fields.union(_trigger_body_fields)
 
 __all__ = ['Request', 'Response']
 
-RequestSourceType = TypeVar('RequestSourceType',
-                            jina_pb2.RequestProto, bytes, str, Dict)
+RequestSourceType = TypeVar(
+    'RequestSourceType', jina_pb2.RequestProto, bytes, str, Dict
+)
 
 
 class Request(ProtoTypeMixin):
@@ -43,10 +50,19 @@ class Request(ProtoTypeMixin):
     :param copy: Copy the request if ``copy`` is True.
     """
 
-    def __init__(self, request: Union[bytes, dict, str, 'jina_pb2.RequestProto', None] = None,
-                 envelope: Optional['jina_pb2.EnvelopeProto'] = None,
-                 copy: bool = False):
-        """Set constructor method."""
+    def __init__(
+        self,
+        request: Optional[Union[bytes, dict, str, 'jina_pb2.RequestProto']] = None,
+        envelope: Optional['jina_pb2.EnvelopeProto'] = None,
+        copy: bool = False,
+    ):
+        """
+        Set constructor method.
+
+        :param request: request object as bytes, dictionary, string or protobuf instance
+        :param envelope: envelope of the request
+        :param copy: if true, request is copied
+        """
         self._buffer = None
         self._pb_body = jina_pb2.RequestProto()  # type: 'jina_pb2.RequestProto'
         try:
@@ -83,7 +99,11 @@ class Request(ProtoTypeMixin):
 
     @property
     def body(self):
-        """Return the request type, raise ``ValueError`` if request_type not set."""
+        """
+        Return the request type, raise ``ValueError`` if request_type not set.
+
+        :return: body property
+        """
         if self._request_type:
             return getattr(self.proto, self._request_type)
         else:
@@ -95,18 +115,28 @@ class Request(ProtoTypeMixin):
 
     @property
     def request_type(self) -> Optional[str]:
-        """Return the request body type, when not set yet, return ``None``."""
+        """
+        Return the request body type, when not set yet, return ``None``.
+
+        :return: request type
+        """
         if self._request_type:
             return self.body.__class__.__name__
 
     def as_typed_request(self, request_type: str):
-        """Change the request class according to the one_of value in ``body``."""
+        """
+        Change the request class according to the one_of value in ``body``.
+
+        :param request_type: string representation of the request type
+        :return: self
+        """
         from .train import TrainRequest
         from .search import SearchRequest
         from .control import ControlRequest
         from .index import IndexRequest
         from .delete import DeleteRequest
         from .update import UpdateRequest
+        from .dump import DumpRequest
 
         rt = request_type.upper()
         if rt.startswith(str(RequestType.TRAIN)):
@@ -121,13 +151,19 @@ class Request(ProtoTypeMixin):
             self.__class__ = UpdateRequest
         elif rt.startswith(str(RequestType.CONTROL)):
             self.__class__ = ControlRequest
+        elif rt.startswith(str(RequestType.DUMP)):
+            self.__class__ = DumpRequest
         else:
             raise TypeError(f'{request_type} is not recognized')
         return self
 
     @request_type.setter
     def request_type(self, value: str):
-        """Set the type of this request, but keep the body empty."""
+        """
+        Set the type of this request, but keep the body empty.
+
+        :param value: string representation of request type
+        """
         value = value.lower()
         if value in _body_type:
             getattr(self.proto, value).SetInParent()
@@ -143,18 +179,23 @@ class Request(ProtoTypeMixin):
         ctag = CompressAlgo.from_string(algorithm)
         if ctag == CompressAlgo.LZ4:
             import lz4.frame
+
             data = lz4.frame.decompress(data)
         elif ctag == CompressAlgo.BZ2:
             import bz2
+
             data = bz2.decompress(data)
         elif ctag == CompressAlgo.LZMA:
             import lzma
+
             data = lzma.decompress(data)
         elif ctag == CompressAlgo.ZLIB:
             import zlib
+
             data = zlib.decompress(data)
         elif ctag == CompressAlgo.GZIP:
             import gzip
+
             data = gzip.decompress(data)
         return data
 
@@ -164,6 +205,8 @@ class Request(ProtoTypeMixin):
         Cast ``self`` to a :class:`jina_pb2.RequestProto`. This will trigger
         :attr:`is_used`. Laziness will be broken and serialization will be recomputed when calling
         :meth:`SerializeToString`.
+
+        :return: protobuf instance
         """
         if self._pb_body:
             # if request is already given while init
@@ -172,7 +215,10 @@ class Request(ProtoTypeMixin):
         else:
             # if not then build one from buffer
             r = jina_pb2.RequestProto()
-            _buffer = self._decompress(self._buffer, self._envelope.compression.algorithm if self._envelope else None)
+            _buffer = self._decompress(
+                self._buffer,
+                self._envelope.compression.algorithm if self._envelope else None,
+            )
             r.ParseFromString(_buffer)
             self.is_used = True
             self._pb_body = r
@@ -186,6 +232,11 @@ class Request(ProtoTypeMixin):
             return r
 
     def SerializeToString(self) -> bytes:
+        """
+        Convert serialized data to string.
+
+        :return: serialized request
+        """
         if self.is_used:
             return self.proto.SerializeToString()
         else:
@@ -194,7 +245,11 @@ class Request(ProtoTypeMixin):
 
     @property
     def queryset(self) -> 'QueryLangSet':
-        """Get the queryset in :class:`QueryLangSet` type."""
+        """
+        Get the queryset in :class:`QueryLangSet` type.
+
+        :return: query lang set
+        """
         self.is_used = True
         return QueryLangSet(self.proto.queryset)
 
